# clarmy02
clarmy02

如何开发一个开源的 Python 扩展包

## 基本步骤

1. 本地功能调通
2. 添加测试用例
3. 测试本地安装成功
4. 构建、上传到 test.pypi.org
5. 测试用 pip 从 test.pypi.org 安装自己的包

## 高阶技巧
https://pyopensourcepkgdevguide.readthedocs.io/zh_CN/latest/index.html